@@ -4,7 +4,7 @@
 
 
 ;;;### (autoloads (perl-minlint-run perl-minlint-mode) "perl-minlint"
-;;;;;;  "perl-minlint.el" (21333 64571 463060 700000))
+;;;;;;  "perl-minlint.el" (21434 26488 351857 56000))
 ;;; Generated autoloads from perl-minlint.el
 
 (autoload 'perl-minlint-mode "perl-minlint" "\
@@ -13,9 +13,11 @@ Run perlminlint in after-save-hook.
 \(fn &optional ARG)" t nil)
 
 (autoload 'perl-minlint-run "perl-minlint" "\
-Run perlminlint for current buffer
+Run perlminlint for current buffer.
+By default, this runs only in perl-minlint-mode.
+To use this in other mode, please give t for optional argument FORCE.
 
-\(fn)" t nil)
+\(fn &optional FORCE)" t nil)
 
 ;;;***
 
